<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ar_SA">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>هناك حياة خارج المتصفح!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>النسخة %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 هو برنامج مجاني و لكن برمجته تستهلك وقتا ثمينا.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>‎الرجاء &lt;a href=&apos;%1&apos;&gt;التبرع&lt;/a&gt; لمتابعة تطوير  %2.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>ارسل الاخطاء و الاراء الى %1</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>صمم الايقونة %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>صمم الواجهة الخفيفة %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>صمم بروكسي HTTP %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>تمت الترجمة بواسطة %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>نشر هذا البرنامج تحت رخصة  &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;اقفل</translation>
    </message>
    <message>
        <source>About</source>
        <translation>عن البرنامج</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>ما اردت معرفته عن %1 و لم تستطع ان تسأل</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>مسح</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/sec</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>seconds</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 متبقي</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>التحميل %n</numerusform>
            <numerusform>التحميل %n</numerusform>
            <numerusform>التحميل %n</numerusform>
            <numerusform>التحميل %n</numerusform>
            <numerusform>التحميل %n</numerusform>
            <numerusform>التحميل %n</numerusform>
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>هذه ليست سوى النسخة التجريبية من %1.</translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>يمكن تحميل الفيديو في أقل من %1  دقيقة بحيث يمكنك اختبار وظيفة التحميل.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>متابعة</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>احصل على النسخة الكاملة</translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>تغيير الموقع...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>اختر موقع التحميل</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>موقع التحميل تغير.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>التحميل سيتم في الموقع السابق.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>التحميل الى:%1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>التحميلات</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Play/Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>ايقاف تشغيل المقطع الحالي</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>المقطع التالي</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>المقطع السابق</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>رفع الصوت</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>خفض الصوت</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>صامت</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>امام</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>خلف</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>جاري البحث...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>اظهر %1 المزيد</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>لا توجد فيديوات</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation> لا توجد فيديوات اخرى</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;قف</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>وقف التشغيل و العودة لوضع البحث</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;القفز</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>القفز للفيديو التالي</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;ايقاف مؤقت</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>ايقاف التشغيل</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;شاشة كاملة</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>تشغيل شاشة كاملة</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;الواجهة الخفيفة</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>اخفاء القائمة و شريط المهام</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>فتح &amp;صفحة YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>اذهب الى صفحة فيديو YouTube و وقف التشغيل</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>نسخ &amp;رابط YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>نسخ رابط YouTube الى clipboard</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>نسخ الفيديو و &amp;الرابط</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>نسخ رابط الفيديو الى clipboard</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;إزالة</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>إزالة الفيديو من القائمة</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>الرفع الى &amp;اعلى</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>رفع المقاطع المختارة الى فوق في القائمة</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>الانزال الى &amp;تحت</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>انزال المقاطع المختارة الى تحت في القائمة</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">&amp;مسح كلمات البحث السابقة</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>مسح تاريخ البحث. لا يمكن استعادته.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;الانتهاء</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>مع السلامة</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;الموقع</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 على الشبكة</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>&amp;التبرع</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>‎الرجاء التبرع لمتابعة تطوير  %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;عن البرنامج</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>معلومات عن %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>كتم الصوت</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;البرنامج</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;القائمة</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;الفيديو</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;المساعدة</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>اضغط %1 لرفع الصوت و %2 لخفضه</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>جاري فتح %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>خطأ قاتل: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>خطأ: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;التشغيل</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>اكمال التشغيل</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>الخروج من &amp;الشاشة الكاملة</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>الوقت المتبقي: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>%1%الصوت عند </translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>الصوت مكتوم</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>الصوت غير مكتوم</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>الوضوح الاقصى %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>خصوصيتك امنة</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;التحميلات</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>عرض تفاصيل عن تحميلات الفيديو</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;التحميلات</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>تحميل الفيديو الحالي</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>هل تريد الخروج %1  رغم وجود تحميل?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>عند اغلاق %1 التحميل سيلغى.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>الاغلاق و الغاء التحميل</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>انتظار انتهاء التحميل</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>التحميل انتهى</translation>
    </message>
    <message>
        <source>&amp;Clear recent searches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>اقرب النتائج</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>الاقرب زمنا</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>الاكثر عرضا</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>يمكنك لصق رابط YouTube في برنامج اخر</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>يمكنك لصق رابط الفيديو في برنامج اخر</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>الرابط سيكون صالحا لمدة محدودة.</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation type="obsolete">انت تشاهد &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>هذه ليست سوى النسخة التجريبية من %1.</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>انها تتيح لك تجربة البرنامج.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>متابعة</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>احصل على النسخة الكاملة</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>جاري تحميل %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>خطأ شبكة:%1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 مشاهدات</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) ? %4</source>
        <translation type="obsolete">%1 of %2 (%3) ? %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>تهيئة</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>فشل</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>تم</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>متوقف</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>ايقاف التحميل</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>اظهار في %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>فتح المجلد الرئيسي</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>اعادة التحميل</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>مرحبا بك في &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation type="obsolete">اختر كلمة بحث للبدء في مشاهدة المقاطع.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>شاهد</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>كلمات بحث سابقة</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>تم ايجاد نسخة جديدة من %1 الرجاء &lt;a href=&apos;%2&apos;&gt;الترقية الى نسخة  %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>اجعل نفسك مرتاحا</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished">احصل على النسخة الكاملة</translation>
    </message>
    <message>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>خطأ شبكة:%1 الى %2</translation>
    </message>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
